clear;
% Include HspiceToolbox
if ispc ==1
    addpath('c:\CppSim\CppSimShared\HspiceToolbox\');
else
    addpath('~/CppSim/CppSimShared/HspiceToolbox');
end

cd C:\CppSim\SimRuns\Sigma_delta_ord2_dt_adc_example\second_order_dt_sigma_delta_adc

%---------------------------------------------------
% Input Parameters

N = 1e5;     % Number of points for FFT
Fs = 1e6;    % Sampling frequency
fin = 1e3;   % Input signal bandwidth
OSR = Fs/2/fin;     % Oversampling ratio
OSR = 500;          % Oversampling ratio
In_FS = sqrt(2);    % Input full-scale
f = Fs/2*linspace(0,1,N/2); % Frequency axis

%---------------------------------------------------
% Load simulation results

% Load the simulation file
x  = loadsig_cppsim('test_out.tr0');
%x  = loadsig_cppsim('test.tr0');

% Extract the output signal v
vl = evalsig(x,'v');
v  = vl(length(vl)-N+1:length(vl))';

%---------------------------------------------------
% Output PSD and SNR

wind_hann = hann(N,'periodic');  % Hanning Window
v_hann = v .* wind_hann';        % Windowed Input

% Sin-wave scaled PSD (see page 372 in Schreier and Temes)
S_vv = ( abs( fft(v_hann,N)) / ((sum(wind_hann) * In_FS/4)) ) .^2;

%Calculating SNR
signal_bins  =  find(S_vv > max(S_vv)/4.1);
signal_power = sum(S_vv(signal_bins));
noise_power  = 2*sum(S_vv(1:length(S_vv)/2/OSR)) - signal_power;
snr_value = 10*log10(signal_power/noise_power)
hd3 = 10*log10(abs(S_vv(signal_bins(2)*3-2)))

%Frequency axis
f = Fs/2*linspace(0,1,N/2);

figure(3)
%hold on
clf
semilogx(f,10*log10(S_vv(1:N/2)),'LineWidth',2)
axis([10 500e3 -200 0])
title('CppSim Output PSD','Fontsize',12);
xlabel('Frequency (Hz)','Fontsize',12);
ylabel('dBFS/NBW','Fontsize',12);
text(3e3,-160,sprintf('SNR = %4.1fdB\n',snr_value))
text(3e3,-170,sprintf('3rd harmonic = %4.1fdBFS\n',hd3))
print -dtiff 'figures/cppsim_psd'
print -dmeta 'figures/cppsim_psd'
